#
# spec file for package encfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Perl-Test-More >= 0.31 is requires by checks but yet not present in SuSE repos
%define do_checks 0

# The cmake macro for distros with cmake 3.3 cannot build encfs
%define use_cmake_macro 1
%if 0%{?suse_version} == 1315 && 0%{?sle_version} == 120100
# Leap 42.1
%define use_cmake_macro 0
%endif
%if 0%{?suse_version} > 1320
%ifarch ppc
%define use_cmake_macro 0
%endif
%endif

# Leap 42.2 and Tumbleweed have tinyxml2-3. For other distribution use the
# tinyxml2-3 that is shipped with encfs.
%define os_has_tinyxml2 0
%if 0%{?leap_version} >= 420200
%ifarch x86_64
%define os_has_tinyxml2 1
%endif
%endif
%if 0%{?suse_version} > 1320
%ifnarch ppc
%define os_has_tinyxml2 1
%endif
%endif

Name:           encfs
Version:        1.9.2
Release:        2.2
Summary:        Userspace Encrypted File System
License:        GPL-2.0+ and GPL-3.0+
Group:          System/Filesystems
Url:            https://vgough.github.io/encfs/
Source:         https://github.com/vgough/encfs/releases/download/v%{version}/encfs-%{version}.tar.gz
BuildRequires:  cmake >= 3.0.2
BuildRequires:  fuse-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if %{os_has_tinyxml2}
BuildRequires:  tinyxml2-devel
%endif
Requires:       fuse
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-lang = %{version}

# requirements for check
%if %{do_checks}
BuildRequires:  fuse
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(File::Copy)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(IO::Handle)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More) => 31
BuildRequires:  perl(Time::HiRes)
%if %{os_has_tinyxml2}
BuildRequires:  libtinyxml2-3
%endif
BuildRequires:  expect
BuildRequires:  openssl
BuildRequires:  zlib
%endif

%description
EncFS provides an encrypted file system, layered on top of a normal
directory tree and encrypts individual files which are stored in the
hosting directory tree.

This has several advantages over the loopback encryption which
provided by the Linux kernel: 
- No space is and has to be reserved, encrypted files only 
  take the space that they really occupy
- Backups: encrypted files can be individually backed-up on the host
  filesystem
- Layering: Since it's hosted on a normal filesystem, encfs can be
  used on filesystems which normally have no support encryption,
  like NFS or other userspace filesystems.

EncFS is implemented as a userspace filesystem in an unprivileged
application using fuse (FUSE (Filesystem in USErspace)).


%lang_package

%prep
%setup 

%build
%if %{use_cmake_macro}
%cmake \
%if %{os_has_tinyxml2}
 -DUSE_INTERNAL_TINYXML:BOOL=OFF
%else
 -DUSE_INTERNAL_TINYXML:BOOL=ON
%endif
%else
mkdir build
cd build
/usr/bin/cmake .. -G"Unix Makefiles" \
 -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
 -DINCLUDE_INSTALL_DIR:PATH=%{_includedir} \
 -DLIB_INSTALL_DIR:PATH=%{_libdir} \
 -DSYSCONF_INSTALL_DIR:PATH=%{_sysconfdir} \
 -DSHARE_INSTALL_PREFIX:PATH=%{_datadir} \
 -DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \
 -DCMAKE_BUILD_TYPE=RelWithDebInfo \
 -DCMAKE_C_FLAGS="${CFLAGS:-%optflags} -DNDEBUG" \
 -DCMAKE_CXX_FLAGS="${CXXFLAGS:-%optflags} -DNDEBUG" \
 -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now" \
 -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now" \
 -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now" \
%if "%{?_lib}" == "lib64" 
 -DLIB_SUFFIX=64 \
%endif  
 -DCMAKE_SKIP_RPATH:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON \
 -DBUILD_SHARED_LIBS:BOOL=ON \
 -DBUILD_STATIC_LIBS:BOOL=OFF \
 -DCMAKE_COLOR_MAKEFILE:BOOL=OFF \
 -DCMAKE_INSTALL_DO_STRIP:BOOL=OFF \
 -DCMAKE_MODULES_INSTALL_DIR=%{_datadir}/cmake/Modules \
%if %{os_has_tinyxml2}
 -DUSE_INTERNAL_TINYXML:BOOL=OFF
%else
 -DUSE_INTERNAL_TINYXML:BOOL=ON
%endif
%endif

make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install
%__install -d -D -m 0755 %{buildroot}%{_libdir}
cp -a build/libencfs.so.* %{buildroot}%{_libdir}
%if %{os_has_tinyxml2}==0
cp -a build/internal/tinyxml2-3.0.0/libtinyxml2.so.* %{buildroot}%{_libdir}
%endif 
chmod 755 "%{buildroot}%{_bindir}/encfssh"

%find_lang %{name}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%check
%if %{do_checks} 
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$(pwd)/build:
./test.sh
%endif

%files 
%defattr(-,root,root)
%doc AUTHORS COPYING* ChangeLog DESIGN.md PERFORMANCE.md README*
%{_mandir}/man?/*
%{_bindir}/encfs*
%{_libdir}/libencfs.so.*
%if %{os_has_tinyxml2}==0
%{_libdir}/libtinyxml2.so.*
%endif

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Jan 17 2018 fvogt@suse.com
- Fix combination of os_has_tinyxml and use_cmake_macro
* Wed Jul 26 2017 wagner-thomas@gmx.at
- update to 1.9.2
  * fix a use-after-free bug that was introduced in v1.9-rc1
  * cast booleans to int before writing the XML config
  * support reading the config file from pipes
  * add "-t" option to set syslog tag
  * allow read/write in standard reverse mode
  * reject empty passwords
  * support building with openssl 1.1
- removed now unneeded 0001-Use-INITIALIZE_EASYLOGGINGPP-in-Error.cpp.patch
* Sun Apr 23 2017 wagner-thomas@gmx.at
- patch 0001-Use-INITIALIZE_EASYLOGGINGPP-in-Error.cpp.patch fixes
  some undefined references. See upstream issue
  https://github.com/vgough/encfs/issues/291
  With this patch, the %%cmake macro can now be used for building if
  version of cmake is greater than 3.3
- improved detection of tinyxml: now builds on more architectures
  and SLE12 SP2
* Sat Mar  4 2017 wagner-thomas@gmx.at
- update to 1.9.1
  * Fix empty log file creation
  * Link with libintl when available
  * add LIB_INSTALL_DIR override during build to aid in customized install
    locations
  * upgrade easylogging++
- update to 1.9
  * switch to CMake
  * OSX build improvements, RPATH setup
  * Drop Boost dependency. Uses tinyxml2 to read existing XML config archives.
  * Drop librlog dependency. Uses easylogging++ for logging.
  * add encfs_create operation
  * replace getdir with readdir
  * cleanup includes and reformat code
  * allow writes in reverse mode when no header is used
  * make use of C++11 (eg std unordered_map in place of GNU internal hashmap)
- split *.mo files to a separate package encfs-lang
- preperation to include checks
- removed cmake-libdir-name.patch and old-perm-checks.patch which are not
  needed any more
- install tinyxml2-3 if not available in the official repos
- configure-fix.patch: also not needed anymore
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Mar  9 2016 p.drouand@gmail.com
- Update to version 1.8.1
  * No short chanlog available; please read
    /usr/share/doc/packages/encfs/ChangeLog
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.8
  * No short chanlog available; please read the ChangeLog file into
    /usr/share/doc/packages/encfs/ChangeLog
- Update Url to new project home
- Use download Url as source
- Copy DESIGN.md, PERFORMANCE.mde and TRANSLATORS into doc directory
- Remove obsolete patchs
  * encfs-1.7.4-fixReverseAbsoluteSymlinks.diff
  * encfs-1.7.4-fix-bashisms.patch
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in encfssh script
- add patches:
  * encfs-1.7.4-fix-bashisms.patch
* Tue Apr  1 2014 wagner-thomas@gmx.at
- applied patchencfs-1.7.4-fixReverseAbsoluteSymlinks.diff from
  https://code.google.com/p/encfs/issues/detail?id=29
  This fixes encoding of symlinks starting with a "/"
- Added patches:
  * encfs-1.7.4-fixReverseAbsoluteSymlinks.diff
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Tue Aug 30 2011 crrodriguez@opensuse.org
- Fix build, axing all m4 macros was a bad idea...
* Fri Dec  3 2010 mszeredi@suse.cz
- updated to version 1.7.4
  * fixes bug with --reverse option setting which causes files to
    be stored incorrectly
* Mon Sep  6 2010 mszeredi@suse.cz
- updated to version 1.7.2
  * allow per-block random bytes to be configured independently of
    per-block MAC.
  * new IV initialization
  * fix component configuration to ease adding flags or config
* Mon Jun 28 2010 mszeredi@suse.cz
- updated to version 1.6.0
  * build fixes
  * add support for version field within serialized config
  * add options to help automate filesystem creation
  * modification and access times can be changed for symlinks
  * try to maintain modtime during rename
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Jun  3 2009 mszeredi@suse.cz
- fix compile error due to missing "const" qualifier
* Wed Oct 29 2008 mszeredi@suse.de
- updated to version 1.5.0
  * fix bug in export - wasn't able to export symlinks (launchpad bug
    [#201974])
  * add makeKey program and showKey option to encfsctl
  * remove logs in Context, which displayed plaintext names
  * use PBKDF2 for key generation with salt and variable iteration
    count
  * allow for automatic upgrade to PBKDF2 when changing passwords
  * enable file hole support by default
* Tue Apr 15 2008 mszeredi@suse.de
- updated to version 1.4.2
  * move buffer management to avoid memory leak in case of decoding
    error
  * reverse encryption support
  * fix rename bug by tracking and applying undo in all error paths
    (launchpad bug #160214)
  * add '-o' option which passes arg through to fuse
  * add -h option
  * add mount-on-demand
  * change license file to GPL3
  * enlarge max password length
  * run extpass command via shell, to allow passing arguments
    to program
  * fix directory rename issue (launchpad bug #183358)
  * no arg required for stdinpass
  * ensure paths end in '/'. fixes (launchpad bug #184905)
  * add zero-block pass-through option, enabling allow-holes code
  * fix bug in export - wasn't able to export symlinks (launchpad
    bug #201974)
  * switch to V6 XML config format
* Wed Oct 24 2007 mszeredi@suse.de
- Fix compile errors and warnings in beta
* Fri Aug 10 2007 bk@suse.de
- Add "Requires: fuse" to ensure that fuse is present (285101#c29)
- Use %%find_lang to mark locale files with missing %%lang (rpmlint)
* Thu Mar 29 2007 meissner@suse.de
- buildrequires zlib-devel
* Thu Feb 15 2007 mszeredi@suse.cz
- updated to version 1.3.2
  * fix failure to process HMAC correctly in case of read error
  * builds with GCC 4.2
  * add workaround for group permission problem in 'public' mode
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.3.1.
  * ports for fuse-2.5
  * bugfixes for null filename encryption
  * fix directory rename error
  * new translations
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 tiwai@suse.de
- fix the build with fuse 2.5.0.
* Tue Nov 15 2005 tiwai@suse.de
- updated to version 1.2.5.
* Fri Sep 30 2005 tiwai@suse.de
- updated to version 1.2.4.
* Wed May 25 2005 tiwai@suse.de
- initial version: 1.2.2
